From 67985f9eb69510800cd53333ce456a72363499d0 Mon Sep 17 00:00:00 2001
From: Amul Sul <amul.sul@enterprisedb.com>
Date: Wed, 31 Jul 2024 11:43:52 +0530
Subject: [PATCH v3 04/11] Refactor: move show_progress and skip_checksums to
 verifier_context struct

---
 src/bin/pg_verifybackup/pg_verifybackup.c | 29 +++++++++++------------
 1 file changed, 14 insertions(+), 15 deletions(-)

diff --git a/src/bin/pg_verifybackup/pg_verifybackup.c b/src/bin/pg_verifybackup/pg_verifybackup.c
index d77e70fbe38..74b3a66835a 100644
--- a/src/bin/pg_verifybackup/pg_verifybackup.c
+++ b/src/bin/pg_verifybackup/pg_verifybackup.c
@@ -113,6 +113,8 @@ typedef struct verifier_context
 	manifest_data *manifest;
 	char	   *backup_directory;
 	SimpleStringList ignore_list;
+	bool		show_progress;
+	bool		skip_checksums;
 	bool		exit_on_error;
 	bool		saw_any_error;
 } verifier_context;
@@ -157,15 +159,11 @@ static void report_fatal_error(const char *pg_restrict fmt,...)
 			pg_attribute_printf(1, 2) pg_attribute_noreturn();
 static bool should_ignore_relpath(verifier_context *context, const char *relpath);
 
-static void progress_report(bool finished);
+static void progress_report(verifier_context *context, bool finished);
 static void usage(void);
 
 static const char *progname;
 
-/* options */
-static bool show_progress = false;
-static bool skip_checksums = false;
-
 /* Progress indicators */
 static uint64 total_size = 0;
 static uint64 done_size = 0;
@@ -260,13 +258,13 @@ main(int argc, char **argv)
 				no_parse_wal = true;
 				break;
 			case 'P':
-				show_progress = true;
+				context.show_progress = true;
 				break;
 			case 'q':
 				quiet = true;
 				break;
 			case 's':
-				skip_checksums = true;
+				context.skip_checksums = true;
 				break;
 			case 'w':
 				wal_directory = pstrdup(optarg);
@@ -299,7 +297,7 @@ main(int argc, char **argv)
 	}
 
 	/* Complain if the specified arguments conflict */
-	if (show_progress && quiet)
+	if (context.show_progress && quiet)
 		pg_fatal("cannot specify both %s and %s",
 				 "-P/--progress", "-q/--quiet");
 
@@ -363,7 +361,7 @@ main(int argc, char **argv)
 	 * Now do the expensive work of verifying file checksums, unless we were
 	 * told to skip it.
 	 */
-	if (!skip_checksums)
+	if (!context.skip_checksums)
 		verify_backup_checksums(&context);
 
 	/*
@@ -739,7 +737,8 @@ verify_backup_file(verifier_context *context, char *relpath, char *fullpath)
 		verify_control_file(fullpath, context->manifest->system_identifier);
 
 	/* Update statistics for progress report, if necessary */
-	if (show_progress && !skip_checksums && should_verify_checksum(m))
+	if (context->show_progress && !context->skip_checksums &&
+		should_verify_checksum(m))
 		total_size += m->size;
 
 	/*
@@ -815,7 +814,7 @@ verify_backup_checksums(verifier_context *context)
 	manifest_file *m;
 	uint8	   *buffer;
 
-	progress_report(false);
+	progress_report(context, false);
 
 	buffer = pg_malloc(READ_CHUNK_SIZE * sizeof(uint8));
 
@@ -841,7 +840,7 @@ verify_backup_checksums(verifier_context *context)
 
 	pfree(buffer);
 
-	progress_report(true);
+	progress_report(context, true);
 }
 
 /*
@@ -890,7 +889,7 @@ verify_file_checksum(verifier_context *context, manifest_file *m,
 
 		/* Report progress */
 		done_size += rc;
-		progress_report(false);
+		progress_report(context, false);
 	}
 	if (rc < 0)
 		report_backup_error(context, "could not read file \"%s\": %m",
@@ -1045,7 +1044,7 @@ should_ignore_relpath(verifier_context *context, const char *relpath)
  * is moved to the next line.
  */
 static void
-progress_report(bool finished)
+progress_report(verifier_context *context, bool finished)
 {
 	static pg_time_t last_progress_report = 0;
 	pg_time_t	now;
@@ -1053,7 +1052,7 @@ progress_report(bool finished)
 	char		totalsize_str[32];
 	char		donesize_str[32];
 
-	if (!show_progress)
+	if (!context->show_progress)
 		return;
 
 	now = time(NULL);
-- 
2.18.0

